@@ -14,7 +14,7 @@ def load_from(filename):
 
         dictionary = load_from("foo.json")
     """
-    with open(filename, encoding="uft-8") as file:
+    with open(filename, encoding="utf-8") as file:
         return json.load(file)
 
 
@@ -27,5 +27,5 @@ def dump_into(filename, payload, indent=2):
 
         dump_into("foo.json", {"key": "value"})
     """
-    with open(filename, "wt", encoding="uft-8") as file:
+    with open(filename, "wt", encoding="utf-8") as file:
         dump(payload, file, indent=indent)
